@@ -15,7 +15,6 @@ import random
 import string
 
 from oslo_log import log as logging
-import six
 
 from senlin.common import context
 from senlin.common import exception as exc
@@ -30,7 +29,7 @@ def GenKubeToken():
         string.digits + string.ascii_lowercase) for i in range(6)])
     token_secret = ''.join([random.choice(
         string.digits + string.ascii_lowercase) for i in range(16)])
-    token = '.'.join(token_id, token_secret)
+    token = '.'.join([token_id, token_secret])
     return token
 
 
@@ -52,21 +51,24 @@ class KubeBaseProfile(server.ServerProfile):
         token = GenKubeToken()
         # store generated token
 
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         data = obj.data
         data[self.KUBEADM_TOKEN] = token
         cluster_obj.Cluster.update(ctx, obj.id, {'data': data})
         return token
 
     def _get_kubeadm_token(self, obj):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             return cluster.data.get(self.KUBEADM_TOKEN)
         return None
 
     def _update_master_ip(self, obj, ip):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             cluster.data['kube_master_ip'] = ip
@@ -74,16 +76,28 @@ class KubeBaseProfile(server.ServerProfile):
 
     def _create_network(self, obj):
         client = self.network(obj)
-        net = client.network_create()
-        subnet = client.subnet_create(network_id=net.id, cidr='10.7.0.0/24',
-                                      ip_version=4)
+        try:
+            net = client.network_create()
+            subnet = client.subnet_create(network_id=net.id,
+                                          cidr='10.7.0.0/24',
+                                          ip_version=4)
+        except exc.InternalError as ex:
+            raise exc.EResourceCreation(type='kubernetes',
+                                        message=str(ex),
+                                        resource_id=obj.id)
         pub_net = client.network_get(self.properties[self.PUBLIC_NETWORK])
-        router = client.router_create(
-            external_gateway_info={"network_id": pub_net.id})
-        client.add_interface_to_router(router, subnet_id=subnet.id)
-        fip = client.floatingip_create(floating_network_id=pub_net.id)
+        try:
+            router = client.router_create(
+                external_gateway_info={"network_id": pub_net.id})
+            client.add_interface_to_router(router, subnet_id=subnet.id)
+            fip = client.floatingip_create(floating_network_id=pub_net.id)
+        except exc.InternalError as ex:
+            raise exc.EResourceCreation(type='kubernetes',
+                                        message=str(ex),
+                                        resource_id=obj.id)
 
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         data = obj.data
         data[self.PRIVATE_NETWORK] = net.id
         data[self.PRIVATE_SUBNET] = subnet.id
@@ -98,50 +112,95 @@ class KubeBaseProfile(server.ServerProfile):
     def _delete_network(self, obj):
         client = self.network(obj)
         fip_id = obj.data.get(self.KUBE_MASTER_FLOATINGIP_ID)
-        client.floatingip_delete(fip_id)
+        if fip_id:
+            try:
+                # delete floating ip
+                client.floatingip_delete(fip_id)
+            except exc.InternalError as ex:
+                raise exc.EResourceDeletion(type='kubernetes', id=fip_id,
+                                            message=str(ex))
 
         router = obj.data.get(self.PRIVATE_ROUTER)
         subnet = obj.data.get(self.PRIVATE_SUBNET)
-        client.remove_interface_from_router(router, subnet_id=subnet)
+        if router and subnet:
+            try:
+                client.remove_interface_from_router(router, subnet_id=subnet)
+            except exc.InternalError as ex:
+                raise exc.EResourceDeletion(type='kubernetes',
+                                            id=subnet,
+                                            message=str(ex))
+
+        if router:
+            try:
+                # delete router
+                client.router_delete(router, ignore_missing=True)
+            except exc.InternalError as ex:
+                raise exc.EResourceDeletion(type='kubernetes',
+                                            id=router,
+                                            message=str(ex))
 
-        # delete router and network
-        client.router_delete(router, ignore_missing=True)
         net = obj.data.get(self.PRIVATE_NETWORK)
-        client.network_delete(net, ignore_missing=True)
+        if net:
+            try:
+                # delete network
+                client.network_delete(net, ignore_missing=True)
+            except exc.InternalError as ex:
+                raise exc.EResourceDeletion(type='kubernetes',
+                                            id=net,
+                                            message=str(ex))
 
     def _associate_floatingip(self, obj, server):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
+
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             fip = cluster.data.get(self.KUBE_MASTER_FLOATINGIP)
-            self.compute(obj).server_floatingip_associate(server, fip)
+            if fip:
+                try:
+                    self.compute(obj).server_floatingip_associate(server,
+                                                                  fip)
+                except exc.InternalError as ex:
+                    raise exc.EResourceOperation(op='floatingip',
+                                                 type='kubernetes',
+                                                 id=fip,
+                                                 message=str(ex))
 
     def _disassociate_floatingip(self, obj, server):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             fip = cluster.data.get(self.KUBE_MASTER_FLOATINGIP)
-            try:
-                self.compute(obj).server_floatingip_disassociate(server, fip)
-            except Exception:
-                pass
+            if fip:
+                try:
+                    self.compute(obj).server_floatingip_disassociate(server,
+                                                                     fip)
+                except exc.InternalError as ex:
+                    raise exc.EResourceOperation(op='floatingip',
+                                                 type='kubernetes',
+                                                 id=fip,
+                                                 message=str(ex))
 
     def _get_cluster_data(self, obj):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             return cluster.data
         return {}
 
     def _get_network(self, obj):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             return cluster.data.get(self.PRIVATE_NETWORK)
         return None
 
     def _create_security_group(self, obj):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         sgid = obj.data.get(self.SECURITY_GROUP, None)
         if sgid:
             return sgid
@@ -150,8 +209,8 @@ class KubeBaseProfile(server.ServerProfile):
         try:
             sg = client.security_group_create(name=self.name)
         except Exception as ex:
-            raise exc.EResourceCreation(type='kubernetes.master',
-                                        message=six.text_type(ex))
+            raise exc.EResourceCreation(type='kubernetes',
+                                        message=str(ex))
         data = obj.data
         data[self.SECURITY_GROUP] = sg.id
         cluster_obj.Cluster.update(ctx, obj.id, {'data': data})
@@ -160,7 +219,8 @@ class KubeBaseProfile(server.ServerProfile):
         return sg.id
 
     def _get_security_group(self, obj):
-        ctx = context.get_service_context(user=obj.user, project=obj.project)
+        ctx = context.get_service_context(user_id=obj.user,
+                                          project_id=obj.project)
         if obj.cluster_id:
             cluster = cluster_obj.Cluster.get(ctx, obj.cluster_id)
             return cluster.data.get(self.SECURITY_GROUP)
@@ -179,13 +239,19 @@ class KubeBaseProfile(server.ServerProfile):
                 try:
                     client.security_group_rule_create(sgid, port, protocol=p)
                 except Exception as ex:
-                    raise exc.EResourceCreation(type='kubernetes.master',
-                                                message=six.text_type(ex))
+                    raise exc.EResourceCreation(type='kubernetes',
+                                                message=str(ex))
 
     def _delete_security_group(self, obj):
         sgid = obj.data.get(self.SECURITY_GROUP)
         if sgid:
-            self.network(obj).security_group_delete(sgid, ignore_missing=True)
+            try:
+                self.network(obj).security_group_delete(sgid,
+                                                        ignore_missing=True)
+            except exc.InternalError as ex:
+                raise exc.EResourceDeletion(type='kubernetes',
+                                            id=sgid,
+                                            message=str(ex))
 
     def do_validate(self, obj):
         """Validate if the spec has provided valid info for server creation.
