@@ -12,7 +12,6 @@
 
 import inspect
 import re
-import six
 import webob
 
 from oslo_config import cfg
@@ -90,7 +89,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
 
     def test_exception_with_non_ascii_chars(self):
         # We set debug to true to test the code path for serializing traces too
-        cfg.CONF.set_override('debug', True, enforce_type=True)
+        cfg.CONF.set_override('debug', True)
         msg = u'Error with non-ascii chars \x80'
 
         class TestException(senlin_exc.SenlinException):
@@ -110,7 +109,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
         self.assertEqual('Internal Server Error', msg['title'])
 
     def test_remote_exception(self):
-        cfg.CONF.set_override('debug', True, enforce_type=True)
+        cfg.CONF.set_override('debug', True)
         error = senlin_exc.ResourceNotFound(type='cluster', id='a')
         exc_info = (type(error), error, None)
         serialized = rpc_common.serialize_remote_exception(exc_info)
@@ -118,7 +117,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
             serialized, ["senlin.common.exception"])
         wrapper = fault.FaultWrapper(None)
         msg = wrapper._error(remote_error)
-        expected_message = six.text_type(remote_error).split('\n', 1)[0]
+        expected_message = str(remote_error).split('\n', 1)[0]
         expected = {
             'code': 404,
             'error': {
@@ -202,7 +201,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
         }
         self.assertEqual(expected, msg)
 
-    def test_internal_server_error_when_exeption_and_parents_not_mapped(self):
+    def test_internal_server_error_when_exception_and_parents_not_mapped(self):
         wrapper = fault.FaultWrapper(None)
 
         class NotMappedException(Exception):
@@ -223,7 +222,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
         self.assertEqual(expected, msg)
 
     def test_should_not_ignore_parent_classes_even_for_remote_ones(self):
-        cfg.CONF.set_override('debug', True, enforce_type=True)
+        cfg.CONF.set_override('debug', True)
 
         error = ClusterNotFoundChild(type='cluster', id='a')
         exc_info = (type(error), error, None)
@@ -233,7 +232,7 @@ class FaultMiddlewareTest(base.SenlinTestCase):
 
         wrapper = fault.FaultWrapper(None)
         msg = wrapper._error(remote_error)
-        expected_message = six.text_type(remote_error).split('\n', 1)[0]
+        expected_message = str(remote_error).split('\n', 1)[0]
         expected = {
             'code': 404,
             'error': {
