@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
 from senlin.common import utils as common_utils
 from senlin.engine import senlin_lock as lockm
@@ -42,7 +42,7 @@ class SenlinLockTest(base.SenlinTestCase):
         mock_acquire.assert_called_once_with('CLUSTER_A', 'ACTION_XYZ',
                                              lockm.CLUSTER_SCOPE)
 
-    @mock.patch.object(common_utils, 'is_engine_dead')
+    @mock.patch.object(common_utils, 'is_service_dead')
     @mock.patch.object(svco.Service, 'gc_by_engine')
     @mock.patch.object(clo.ClusterLock, "acquire")
     @mock.patch.object(clo.ClusterLock, "steal")
@@ -56,52 +56,56 @@ class SenlinLockTest(base.SenlinTestCase):
                                          'NEW_ENGINE')
 
         self.assertTrue(res)
-        mock_acquire.assert_called_once_with("CLUSTER_A", "ACTION_XYZ",
-                                             lockm.CLUSTER_SCOPE)
+        mock_acquire.assert_called_with("CLUSTER_A", "ACTION_XYZ",
+                                        lockm.CLUSTER_SCOPE)
+        self.assertEqual(3, mock_acquire.call_count)
         mock_steal.assert_called_once_with('CLUSTER_A', 'ACTION_XYZ')
         mock_gc.assert_called_once_with(mock.ANY)
 
-    @mock.patch.object(common_utils, 'is_engine_dead')
+    @mock.patch.object(common_utils, 'is_service_dead')
     @mock.patch.object(clo.ClusterLock, "acquire")
     def test_cluster_lock_acquire_failed(self, mock_acquire, mock_dead):
         mock_dead.return_value = False
-        mock_acquire.return_value = 'ACTION_ABC'
+        mock_acquire.return_value = ['ACTION_ABC']
 
         res = lockm.cluster_lock_acquire(self.ctx, 'CLUSTER_A', 'ACTION_XYZ')
 
         self.assertFalse(res)
-        mock_acquire.assert_called_once_with('CLUSTER_A', 'ACTION_XYZ',
-                                             lockm.CLUSTER_SCOPE)
+        mock_acquire.assert_called_with('CLUSTER_A', 'ACTION_XYZ',
+                                        lockm.CLUSTER_SCOPE)
+        self.assertEqual(3, mock_acquire.call_count)
 
     @mock.patch.object(clo.ClusterLock, "acquire")
     @mock.patch.object(clo.ClusterLock, "steal")
     def test_cluster_lock_acquire_forced(self, mock_steal, mock_acquire):
-        mock_acquire.side_effect = ['ACTION_ABC']
+        mock_acquire.return_value = ['ACTION_ABC']
         mock_steal.return_value = ['ACTION_XY']
 
         res = lockm.cluster_lock_acquire(self.ctx, 'CLUSTER_A',
                                          'ACTION_XY', forced=True)
 
         self.assertTrue(res)
-        mock_acquire.assert_called_once_with('CLUSTER_A', 'ACTION_XY',
-                                             lockm.CLUSTER_SCOPE)
+        mock_acquire.assert_called_with('CLUSTER_A', 'ACTION_XY',
+                                        lockm.CLUSTER_SCOPE)
+        self.assertEqual(3, mock_acquire.call_count)
         mock_steal.assert_called_once_with('CLUSTER_A', 'ACTION_XY')
 
-    @mock.patch.object(common_utils, 'is_engine_dead')
+    @mock.patch.object(common_utils, 'is_service_dead')
     @mock.patch.object(clo.ClusterLock, "acquire")
     @mock.patch.object(clo.ClusterLock, "steal")
     def test_cluster_lock_acquire_steal_failed(self, mock_steal, mock_acquire,
                                                mock_dead):
         mock_dead.return_value = False
-        mock_acquire.side_effect = ['ACTION_ABC']
+        mock_acquire.return_value = ['ACTION_ABC']
         mock_steal.return_value = []
 
         res = lockm.cluster_lock_acquire(self.ctx, 'CLUSTER_A',
                                          'ACTION_XY', forced=True)
 
         self.assertFalse(res)
-        mock_acquire.assert_called_once_with('CLUSTER_A', 'ACTION_XY',
-                                             lockm.CLUSTER_SCOPE)
+        mock_acquire.assert_called_with('CLUSTER_A', 'ACTION_XY',
+                                        lockm.CLUSTER_SCOPE)
+        self.assertEqual(3, mock_acquire.call_count)
         mock_steal.assert_called_once_with('CLUSTER_A', 'ACTION_XY')
 
     @mock.patch.object(clo.ClusterLock, "release")
@@ -120,7 +124,7 @@ class SenlinLockTest(base.SenlinTestCase):
         self.assertTrue(res)
         mock_acquire.assert_called_once_with('NODE_A', 'ACTION_XYZ')
 
-    @mock.patch.object(common_utils, 'is_engine_dead')
+    @mock.patch.object(common_utils, 'is_service_dead')
     @mock.patch.object(ao.Action, 'mark_failed')
     @mock.patch.object(nlo.NodeLock, "acquire")
     @mock.patch.object(nlo.NodeLock, "steal")
@@ -140,7 +144,7 @@ class SenlinLockTest(base.SenlinTestCase):
             self.ctx, 'ACTION_ABC', mock.ANY,
             'Engine died when executing this action.')
 
-    @mock.patch.object(common_utils, 'is_engine_dead')
+    @mock.patch.object(common_utils, 'is_service_dead')
     @mock.patch.object(nlo.NodeLock, "acquire")
     def test_node_lock_acquire_failed(self, mock_acquire, mock_dead):
         mock_dead.return_value = False
