@@ -10,8 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
 import testtools
+from unittest import mock
 
 from senlin.common import consts
 from senlin.events import base
@@ -50,8 +50,8 @@ class TestDatabase(testtools.TestCase):
                 'otype': 'CLUSTER',
                 'oname': 'cluster1',
                 'cluster_id': 'CLUSTER_ID',
-                'user': self.context.user,
-                'project': self.context.project,
+                'user': self.context.user_id,
+                'project': self.context.project_id,
                 'action': 'ACTION',
                 'status': 'STATUS',
                 'status_reason': 'REASON',
@@ -83,8 +83,8 @@ class TestDatabase(testtools.TestCase):
                 'otype': 'NODE',
                 'oname': 'node1',
                 'cluster_id': 'CLUSTER_ID',
-                'user': self.context.user,
-                'project': self.context.project,
+                'user': self.context.user_id,
+                'project': self.context.project_id,
                 'action': 'ACTION',
                 'status': 'S1',
                 'status_reason': 'R1',
@@ -113,8 +113,8 @@ class TestDatabase(testtools.TestCase):
                 'otype': 'CLUSTER',
                 'oname': 'cluster1',
                 'cluster_id': 'CLUSTER_ID',
-                'user': self.context.user,
-                'project': self.context.project,
+                'user': self.context.user_id,
+                'project': self.context.project_id,
                 'action': 'dance',
                 'status': 'STATUS',
                 'status_reason': 'REASON',
