@@ -22,7 +22,7 @@ class TestRequestContext(base.SenlinTestCase):
             'auth_token_info': {'123info': 'woop'},
             'user_name': 'mick',
             'user_domain_name': 'user-domain-name',
-            'project': 'project-id',
+            'project_id': 'project-id',
             'project_name': 'a project',
             'project_domain_name': 'a project domain',
             'domain_name': 'this domain',
@@ -40,7 +40,7 @@ class TestRequestContext(base.SenlinTestCase):
             auth_token_info=self.ctx.get('auth_token_info'),
             user_name=self.ctx.get('user_name'),
             user_domain_name=self.ctx.get('user_domain_name'),
-            project=self.ctx.get('project'),
+            project_id=self.ctx.get('project_id'),
             project_name=self.ctx.get('project_name'),
             project_domain_name=self.ctx.get('project_domain_name'),
             domain_name=self.ctx.get('domain_name'),
